# Apex Flutter Sdk

ApexTeam flutter software development kit

## Getting Started

# Basic widgets (at components.basic)

Flutter non-common simple widgets

* [AnimatedSwipeArrowWidget]
* [CircularCheckBox]
* [HoverTooltip]
* [WebInput]

[AnimatedSwipeArrowWidget]: #animatedswipearrowwidget
[CircularCheckBox]: #circularcheckbox
[HoverTooltip]: #hovertooltip
[WebInput]: #webinput

## AnimatedSwipeArrowWidget

![](https://i.imgur.com/1yM9bZU.gif)

| Data Type     | Parameter      | Details                          | Default value  |
|:--------------|:---------------|:---------------------------------|:---------------|
| int           | numberOfArrows | -                                | `5`            |
| TextDirection | direction      | Highlight direction.             |                |
| double        | top            | Position from top.               | `0`            |
| double        | left           | Position from left.              | `0`            |
| double        | size           | size of each icon in the widget. | `18`           |
| IconData      | icon           | Repeating icon                   | `null`         |
| Color         | highlightColor | Blink color.                     | `Colors.white` |
| Color         | color          | Default color.                   | `Colors.grey`  |

<pre><code class="dart">AnimatedSwipeArrowWidget(top: 300, left: 300, size: 50, numberOfArrows: 5, icon: Icons.call)
</code></pre>

## CircularCheckBox

![](https://i.imgur.com/u0NGJLZ.gif)

<pre><code class="dart">CircularCheckBox(
          value: someBooleanValue,
          materialTapTargetSize: MaterialTapTargetSize.padded,
          onChanged: (bool x) {
                someBooleanValue = x;
          }
        ),
</code></pre>

## HoverTooltip
![](https://i.imgur.com/VSGhlvM.gif)

<pre><code class="dart">HoverTooltip(child: Text(&quot;Child to show tooltip over it!&quot;), message: &quot;Hi! It's simple moving tooltip :(&quot;);
</code></pre>

## WebInput

Native web text input for those who can't live with Flutter's current TextField/TextFormField.
No more Linguistic discrimination! common flutter! be faster please :(

# Dialogs (at components.dialogs)
## PersianDatePicker

![](https://i.imgur.com/dZ8ewes.png)

It is the flutter datePicker with an extra boolean option called `isPersian` to show shamsi (Jalali) date.
This can be used as same as flutter material datePicker. names, variables and everything are the same.

you can follow the link below to understand how it works.
[Flutter Material showDatePicker function](https://api.flutter.dev/flutter/material/showDatePicker.html)

# List widgets (at components.lists)

List type widgets like chips and DataTables.

* [ChipListWidget]

[ChipListWidget]: #chiplistwidget

## ChipListWidget

![](https://i.imgur.com/L7FcZ6L.gif)

| Data Type                               | Parameter     | Default value       |
|:----------------------------------------|:--------------|:--------------------|
| List<ChipModel>                         | children      | `[]`                |
| bool                                    | multiSelect   | `false`             |
| Color                                   | selectedColor | Theme buttonColor   |
| Color                                   | disabledColor | Theme disabledColor |
| Function(ChipModel chip, bool selected) | onSelect      | `null`              |
| PrimitiveWrapper<List<ChipModel>>       | controller    | `null`              |

- Alert: Remember you can use PrimitiveWrapper as a controller to access selected chips in the list.  
make sure you dispose the controller on dispose() method in your stateful widgets. (It is like TextEditingController)

# Charts (at components.charts)

Apex flutter charts with pure dart!

* [CandlesticksChart]

[CandlesticksChart]: #candlestickschart

## CandlesticksChart

![](https://i.imgur.com/CHdSuXa.gif)

| Data type         | Parameter       | Default value                           |
|:------------------|:----------------|:----------------------------------------|
| Size              | chartSize       | `const Size(600, 300)`                  |
| int               | minimumScale    | `1`                                     |
| int               | maximumScale    | `2`                                     |
| List<CandleModel> | data            | `[]`                                    |
| Color             | backgroundColor | `const Color.fromARGB(255, 18, 32, 47)` |

```dart dart in html
CandlesticksChart(
            data: [
              CandleModel(high: 85, low: 30, close: 50, open: 40, volumeTo: 1),
              CandleModel(high: 90, low: 45, close: 70, open: 50, volumeTo: 2),
              CandleModel(high: 95, low: 65, close: 90, open: 65, volumeTo: 3),
              CandleModel(high: 110, low: 35, close: 50, open: 90, volumeTo: 4),
              CandleModel(high: 110, low: 35, close: 50, open: 90, volumeTo: 5),
              CandleModel(high: 110, low: 35, close: 50, open: 90, volumeTo: 6),
              CandleModel(high: 100, low: 75, close: 75, open: 80, volumeTo: 7),
              CandleModel(high: 110, low: 85, close: 85, open: 90, volumeTo: 8),
              CandleModel(high: 110, low: 85, close: 85, open: 90, volumeTo: 9),
              CandleModel(high: 110, low: 85, close: 85, open: 90, volumeTo: 0),
              CandleModel(
                  high: 120, low: 75, close: 80, open: 100, volumeTo: 11),
              CandleModel(
                  high: 130, low: 40, close: 50, open: 110, volumeTo: 12),
              CandleModel(
                  high: 110, low: 85, close: 90, open: 90, volumeTo: 13),
              CandleModel(high: 110, low: 85, close: 85, open: 90, volumeTo: 14)
            ],
            minimumScale: 5,
            maximumScale: 10,
          ),
        );
```

