import 'dart:async';

import 'package:flutter/material.dart';

class AnimatedSwipeArrowWidget extends StatefulWidget {
  final int numberOfArrows;
  final TextDirection direction;
  final double top, left;
  final double size;
  final IconData icon;
  final Color highlightColor;
  final Color color;

  const AnimatedSwipeArrowWidget({
    Key key,
    this.numberOfArrows = 5,
    this.direction = TextDirection.rtl,
    this.top = 0,
    this.left = 0,
    this.size = 18,
    this.icon,
    this.highlightColor = Colors.white,
    this.color = Colors.grey,
  }) : super(key: key);

  @override
  _AnimatedSwipeArrowWidgetState createState() =>
      _AnimatedSwipeArrowWidgetState();
}

class _AnimatedSwipeArrowWidgetState extends State<AnimatedSwipeArrowWidget> {
  int _highlightIndex = 0;

  @override
  void initState() {
    super.initState();

    Timer.periodic(Duration(milliseconds: 100), (Timer timer) {
      if (_highlightIndex < widget.numberOfArrows) {
        _highlightIndex++;
      } else {
        _highlightIndex = 0;
      }
      if (mounted) setState(() {});
    });
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: <Widget>[
        for (int i = 0; i < widget.numberOfArrows; i++)
          Positioned(
            top: widget.top,
            left: widget.left,
            child: widget.direction == TextDirection.rtl
                ? Padding(
                    padding: EdgeInsets.only(left: (i * widget.size / 1.8)),
                    child: _buildIcon(i))
                : Padding(
                    padding: EdgeInsets.only(right: (i * widget.size / 1.8)),
                    child: _buildIcon(i)),
          )
      ],
    );
  }

  _buildIcon(int i) {
    if (widget.icon == null)
      return Icon(
        widget.direction == TextDirection.rtl
            ? Icons.chevron_right
            : Icons.chevron_left,
        color: i == _highlightIndex ? widget.highlightColor : widget.color,
        size: widget.size,
      );

    return Icon(
      widget.icon,
      color: i == _highlightIndex ? widget.highlightColor : widget.color,
      size: widget.size,
    );
  }
}
