import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';

class HoverTooltip extends StatefulWidget {
  final Widget child;
  final Widget tooltip;
  final String message;

  const HoverTooltip(
      {Key key, this.message, @required this.child, this.tooltip})
      : super(key: key);

  @override
  _HoverTooltipState createState() => _HoverTooltipState();
}

class _HoverTooltipState extends State<HoverTooltip> {
  OverlayEntry _overlayEntry;

  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      overflow: Overflow.visible,
      children: <Widget>[
        if (widget.child != null)
          _TargetWidget(
            child: widget.child,
            onOffsetChange: (o) {
              this._overlayEntry.remove();
              this._overlayEntry = this._createOverlayEntry(o);
              Overlay.of(context).insert(this._overlayEntry);
            },
            onEnter: (e) {
              this._overlayEntry = this._createOverlayEntry(e.position);
              Overlay.of(context).insert(this._overlayEntry);
            },
            onExit: () {
              this._overlayEntry?.remove();
            },
          ),
      ],
    );
  }

  OverlayEntry _createOverlayEntry(Offset o) {
    RenderBox renderBox = context.findRenderObject();
//    var size = renderBox.size;
//    var offset = renderBox.localToGlobal(Offset.zero);

    return OverlayEntry(
        builder: (context) => Positioned(
              left: o.dx + 10,
              top: o.dy + 10,
              child: widget.tooltip != null
                  ? Material(child: widget.tooltip)
                  : TooltipWidget(
                      text: widget.message,
                    ),
            ));
  }
}

class TooltipWidget extends StatelessWidget {
  final String text;

  const TooltipWidget({Key key, this.text}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final theme = Theme.of(context);
    BoxDecoration defaultDecoration;
    TextStyle defaultTextStyle;
    if (theme.brightness == Brightness.dark) {
      defaultTextStyle = theme.textTheme.bodyText2.copyWith(
        color: Colors.black,
      );
      defaultDecoration = BoxDecoration(
        color: Colors.white.withOpacity(0.9),
        borderRadius: const BorderRadius.all(Radius.circular(4)),
      );
    } else {
      defaultTextStyle = theme.textTheme.bodyText2.copyWith(
        color: Colors.white,
      );
      defaultDecoration = BoxDecoration(
        color: Colors.grey[700].withOpacity(0.9),
        borderRadius: const BorderRadius.all(Radius.circular(4)),
      );
    }
    return Container(
      decoration: defaultDecoration,
      padding: EdgeInsets.all(8),
      child: Text(
        text ?? "",
        style: defaultTextStyle,
      ),
    );
  }
}

class _TargetWidget extends StatelessWidget {
  final Widget child;
  final Function(PointerEnterEvent e) onEnter;
  final VoidCallback onExit;
  final VoidCallback onHover;
  final Function(Offset offset) onOffsetChange;

  const _TargetWidget(
      {Key key,
      this.child,
      this.onOffsetChange,
      this.onEnter,
      this.onExit,
      this.onHover})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MouseRegion(
        onHover: (e) {
          onOffsetChange(e.position);
        },
        onEnter: (e) {
          onEnter(e);
        },
        onExit: (e) {
          onExit();
        },
        child: child);
  }
}
