import 'dart:html' as html;
import 'dart:ui' as ui;

import 'package:apex_flutter_sdk/util/widget_load.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart' as intl;

class WebInput extends StatefulWidget {
  final Size size;
  final EdgeInsets padding;
  final String placeholder;
  final Color placeholderColor;
  final String value;
  final Map<String, String> cssStyles;
  final Function(String) onChange;
  final bool disabled;
  final bool readOnly;
  final bool multiLine;
  final bool obfuscate;
  final int maxLength;
  final int maxLines;
  final TextDirection textDirection;
  final BoxDecoration boxDecoration;
  final TextStyle textStyle;
  final Function(bool isFocused) onFocusChange;

  const WebInput({
    Key key,
    @required this.size,
    this.textStyle,
    this.placeholder,
    this.value,
    this.cssStyles,
    this.onChange,
    this.disabled = false,
    this.textDirection,
    this.readOnly = false,
    this.maxLength,
    this.maxLines,
    this.multiLine = false,
    this.obfuscate = false,
    this.boxDecoration,
    this.padding,
    this.placeholderColor = Colors.grey,
    this.onFocusChange,
  }) : super(key: key);

  @override
  _WebInputState createState() => _WebInputState();
}

class _WebInputState extends State<WebInput> with WidgetLoadMixin {
  Widget _inputWidget;
  var _inputElement;

  @override
  void initState() {
    if (widget.multiLine) {
      _inputElement = html.TextAreaElement();
      _inputElement.rows = widget.maxLines;
      _inputElement.style.resize = 'none';
    } else {
      _inputElement = html.InputElement();
      _inputElement.type = widget.obfuscate ? 'password' : 'text';
      if (widget.size != null) {
        _inputElement.width = widget.size.width.toInt() - 1;
        _inputElement.height = widget.size.height.toInt() - 1;
      }
    }

    _inputElement.value = widget.value ?? '';
    _inputElement.placeholder = widget.placeholder ?? '';

    _inputElement.style.backgroundColor = 'transparent';
    _inputElement.style.border = 'none';
    _inputElement.style.outline = 'none';

    if (widget.cssStyles != null) {
      widget.cssStyles.forEach((key, value) {
        _inputElement.style.setProperty(key, value);
      });
    }
    _inputElement.disabled = widget.disabled;

    _inputElement.onInput.listen((event) {
      if (widget.onChange != null) widget.onChange(_inputElement.value);
    });

    if (widget.maxLength != null) {
      _inputElement.maxLength = widget.maxLength;
    }
    _inputElement.readOnly = widget.readOnly;

    _inputElement.onFocus.listen((event) {
      if (widget.onFocusChange != null) widget.onFocusChange(true);
    });

    ui.platformViewRegistry.registerViewFactory(
        'input_element', (int viewId) => _inputElement..id = "input$viewId");

    _inputWidget = HtmlElementView(
      key: UniqueKey(),
      viewType: 'input_element',
    );

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      padding: widget.padding ?? EdgeInsets.all(4),
      width: widget.size.width,
      height: widget.size.height,
      decoration: widget.boxDecoration,
      child: _inputWidget,
    );
  }

  @override
  void onLoad(BuildContext context) {
    _inputElement.dir = widget.textDirection != null
        ? (widget.textDirection == TextDirection.ltr ? 'ltr' : 'rtl')
        : intl.Bidi.isRtlLanguage(Localizations.localeOf(context).languageCode)
            ? 'rtl'
            : 'ltr';
    if (widget.textStyle == null) {
      _inputElement.style.fontFamily =
          Theme.of(context).textTheme.bodyText1.fontFamily;
      _inputElement.style.fontSize =
          '${Theme.of(context).textTheme.bodyText1.fontSize}px';
    } else {
      _inputElement.style.fontFamily = widget.textStyle.fontFamily;
      _inputElement.style.fontSize =
          '${widget.textStyle.fontSize.toString()}px';
      _inputElement.style.fontWeight = widget.textStyle.fontWeight;
    }
  }
}
