import 'package:apex_flutter_sdk/components/models/chip_model.dart';
import 'package:apex_flutter_sdk/helpers/variables.dart';
import 'package:flutter/material.dart';

class ChipListWidget extends StatefulWidget {
  final List<ChipModel> children;
  final bool multiSelect;
  final Color selectedColor;
  final Color unSelectedColor;
  final Function(ChipModel chip, bool selected) onSelect;
  final PrimitiveWrapper<List<ChipModel>> controller;

  ChipListWidget(
      {Key key,
      @required this.children,
      this.multiSelect = false,
      this.selectedColor,
      this.unSelectedColor,
      this.onSelect,
      this.controller})
      : super(key: key);

  @override
  _ChipListWidgetState createState() => _ChipListWidgetState();
}

class _ChipListWidgetState extends State<ChipListWidget> {
  List<ChipModel> _selectedChips = [];

  @override
  void initState() {
    super.initState();

    for (int i = 0; i < widget.children.length; i++)
      if (widget.children[i].selectedByDefault) {
        _selectedChips.add(widget.children[i]);
        if (!widget.multiSelect) break;
      }

    if (widget.controller != null) {
      widget.controller(_selectedChips);
    }
  }

  @override
  Widget build(BuildContext context) {
    return Wrap(
      spacing: 8,
      crossAxisAlignment: WrapCrossAlignment.start,
      alignment: WrapAlignment.start,
      runSpacing: 0,
      children: [
        for (int i = 0; i < widget.children.length; i++)
          GestureDetector(
            onTap: () {
              if (widget.multiSelect) {
                if (!_selectedChips.contains(widget.children[i])) {
                  _selectedChips.add(widget.children[i]);
                  if (widget.onSelect != null)
                    widget.onSelect(widget.children[i], true);
                } else {
                  _selectedChips.removeWhere((e) => e == widget.children[i]);

                  if (widget.onSelect != null)
                    widget.onSelect(widget.children[i], false);
                }
              } else if (!_selectedChips.contains(widget.children[i])) {
                _selectedChips.clear();

                _selectedChips.add(widget.children[i]);
                if (widget.onSelect != null)
                  widget.onSelect(widget.children[i], true);
              }
              if (mounted) setState(() {});

              if (widget.controller != null) {
                widget.controller(_selectedChips);
              }
            },
            child: Chip(
              label: widget.children[i].label,
              backgroundColor: _selectedChips.contains(widget.children[i])
                  ? widget.selectedColor ?? Theme.of(context).buttonColor
                  : widget.unSelectedColor ?? Theme.of(context).disabledColor,
            ),
          ),
      ],
    );
  }
}
